<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="hu" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategória:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Torrent indítása</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Újraellenőrzés kihagyása</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Almappa létrehozása</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrentkezelési mód:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Nem kategorizált</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Kategória hozzáadása…</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Kategória eltávolítása</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Nem használt kategóriák eltávolítása</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Torrentek folytatása</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Torrentek szüneteltetése</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Torrentek törlése</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Új kategória</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Kategória szerkesztése…</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>qBittorrent bezárása</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Soronként csak egy link</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Globális feltöltési korlátnak 0-nál nagyobbnak, vagy kikapcsoltnak kell lennie.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Globális letöltési korlátnak 0-nál nagyobbnak, vagy kikapcsoltnak kell lennie.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatív feltöltési korlátnak 0-nál nagyobbnak, vagy kikapcsoltnak kell lennie.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatív letöltési korlátnak 0-nál nagyobbnak, vagy kikapcsoltnak kell lennie.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Maximum aktív letöltéseknek nagyobbnak kell lennie, mint -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Maximum aktív feltöltéseknek nagyobbnak kell lennie, mint -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Maximum aktív torrenteknek nagyobbnak kell lennie, mint -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>A maximális kapcsolatok számának 0-nál nagyobbnak, vagy kikapcsoltnak kell lennie.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>A maximális kapcsolatok számának torrentenként 0-nál nagyobbnak, vagy kikapcsoltnak kell lennie.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>A maximális feltöltési szálak korlátnak torrentenként 0-nál nagyobbnak, vagy kikapcsoltnak kell lennie.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Nem sikerült menteni a beállításokat. A qBittorrent valószínüleg nem elérhető.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent a Freenode-on</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>A megosztási arány 0 és 9998 között kell legyen.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>A megosztási időkorlát 0 és 525600 perc között kell legyen.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>A bejövő kapcsolatokhoz használt portnak 1024 és 65535 közé kell esnie.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>A Web UI-hoz használt portnak 1024 és 65535 közé kell esnie.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Nem sikerült bejelentkezni, qBittorrent talán elérhetetlen.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Érvénytelen felhasználónév vagy Jelszó.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Bejelentkezés</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Eredeti szerzők - fejlesztők</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Alkalmaz</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hozzáad</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Torrentek feltöltése</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Fájlok mentési helye:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Süti:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Ide írja be a könyvtár nevét </translation>
    </message>
    <message>
        <source>More information</source>
        <translation>További információ</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Információk a tanúsítványokról</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Hely megadása</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Feltöltési sebesség korlátozása</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Letöltési sebesség korlátozása</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Torrent átnevezése</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Egyéb...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Hétfő</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Kedd</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Szerda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Csütörtök</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Péntek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Szombat</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Vasárnap</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Torrent letöltése URL-ről vagy Magnet linkről</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Helyi torrent feltöltése</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Egészen biztos, hogy törlöd a kiválasztott torrenteket az átviteli listáról?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorent kliens nem elérhető</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Letöltési szálak számának 0-nál nagyobbnak, vagy kikapcsoltnak kell lennie.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Érvénytelen kategórianév:\nNe használjon különleges karaktereket a kategórianévben.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Kategória nem hozható létre</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Feltöltési sebességnek nagyobbnak kell lennie, mint 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Szabad lemezterület: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>A Torrent inaktivitás időzítőjének nagyobbnak kell lennie mint 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Mentéskezelés</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>A letöltési korlátnak nagyobbnak kell lennie, mint 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent le lett állítva</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Eszközök</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Nézet</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Beállítások...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Minimum priorítás</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Top priorítás</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Prioritás csökkentése</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Prioritás növelése</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Felső eszköztár</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Állapotsor</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Sebesség a címsoron</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Adományozz!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Összes folytatása</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statisztika</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Összes szüneteltetése</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Torrent fájl hozzáadása...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentáció</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Torrent Link Hozzáadása...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Igen</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nem</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Globális feltöltési sebességkorlát</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Globális letöltési sebességkorlát</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Biztosan ki akar lépni a qBittorrentből?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[L: %1/s, F: %2/s] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternatív sebességkorlátok</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Keresőmotor</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Torrent lista szűrése...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Átvitelek</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Kapcsolat</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Sebesség</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Webes felület</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Nyelv</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Felhasználói felület nyelve:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>E-mail értesítés letöltés végeztével</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Külső program indítása letöltés végeztével</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP-szűrés</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Alternatív sebességkorlátok ütemezése</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrent ütemezés</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Torrent megosztása a megosztási idői lejártáig</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Ezen követők automatikus hozzáadása az új letöltésekhez:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Webes felhasználói felület (Távoli elérés)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP-cím:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Szerver domainek:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>HTTPS használata HTTP helyett</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Hitelesítés mellőzése a helyi gépen lévő klienseknél</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Hitelesítés mellőzése a fehérlistára tett IP alhálózatokban lévő klienseknél</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Dinamikus domain név frissítése</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Átmeneti fájlok helye:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>.torrent fájlok másolása ide:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Elkészült letöltések .torrent fájlainak másolása a következő helyre:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Fájlok helyének lefoglalása előre</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>.!qB kiterjesztés használata félkész fájloknál</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Torrentek hozzáadása innen:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP-kiszolgáló:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Ez a kiszolgáló biztonságos kapcsolatot (SSL) igényel</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Hitelesítés</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Engedélyezett protokoll:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP és μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Figyelő port</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port a bejövő kapcsolatokhoz:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>UPnP / NAT-PMP használata a portok átirányítására</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Különböző port használata minden indításnál</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Kapcsolati korlátok</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Kapcsolatok maximális száma torrentenként:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Kapcsolatok maximális száma:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Feltöltési szálak száma torrentenként:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Feltöltési szálak maximális száma:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proxy kiszolgáló</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Nincs)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Kiszolgáló:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Proxy használata az ügyfélkapcsolatokhoz</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>A proxik által nem támogatott kapcsolatok tiltása</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Csak a torrentekhez használjon proxyt</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Szűrő útvonala (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Kézzel tiltott IP-címek…</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Alkalmazás a trackerekre</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Globális sebességkorlátok</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Feltöltés:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Letöltés:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternatív sebességkorlátok</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Ettől:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Eddig:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Ekkor:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Minden nap</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Hétköznapokon</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Hétvégéken</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Sebességkorlátok beállítása</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Korlátok alkalmazása az átviteli többletre is</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Korlátok alkalmazása µTP protokollra is</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Magánszféra</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>DHT (decentralizált hálózat) engedélyezése, hogy több ügyfélt találjon</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Ügyfélcsere (PeX) engedélyezése, hogy több ügyfelet találjon</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Helyi ügyfelek felkutatásának (LPD) engedélyezése, hogy több ügyfelet találjon</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Titkosítás módja:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Titkosítás előnyben részesítése</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Titkosítás megkövetelése</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Titkosítás kikapcsolása</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Névtelen mód engedélyezése</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Aktív letöltések maximális száma:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Aktív feltöltések maximális száma:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Torrentek maximális száma:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>A lassú torrentek figyelmen kívül hagyása a korlátoknál</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Megosztási arány korlátozása</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Torrentek megosztása eddig az arányig</translation>
    </message>
    <message>
        <source>then</source>
        <translation>aztán</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Eltávolítás</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>UPnP / NAT-PMP használata a portok átirányítására</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Tanúsítvány:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Kulcs:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Regisztráció</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Domain név:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Támogatott paraméterek (kis- és nagybetű érzékeny):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrent neve</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategória</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation>%G: Címkék (vesszővel elválasztva)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Tartalom útvonala (többfájlok torrenteknél ugyanaz mint a gyökér útvonal)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Gyökér útvonala (első torrent alkönyvtár útvonala)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Mentés útvonala</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Fájlok száma</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrent mérete (bájtok)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Jelenlegi követő</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Hash információ</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Tipp: Tegye a paramétereket idézőjelbe, hogy elkerülje azt, hogy az üres karaktereknél kettévágásra kerüljenek (például "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>A webes felület felhasználónevének legalább 3 karakter hosszúnak kell lennie.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>A webes felület jelszavának legalább 6 karakter hosszúnak kell lennie.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>perc</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Kattintáseltérítés védelem engedélyezése</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Engedélyezze a kereszt webhely kérelem hamisítás védelmét</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Ezután törölje a .torrent fájlokat</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Letöltési aránykorlát:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Feltöltési aránykorlát:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Jelenlegi jelszó megváltoztatása</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Alternatív webes UI használata</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Alapértelmezett mentési útvonal:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Az alternatív webes felhasználói felületfájlok helye nem lehet üres.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Ne induljon el a letöltés automatikusan</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Torrent kézi módba váltása</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Amikor a torrent kategória megváltozik:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Érintett torrentek áthelyezése</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Korlátok alkalmazása a LAN kapcsolatokra is</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 azt jelenti, hogy korlátlan</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Torrent áthelyezése</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Amikor az alapértelmezett mentési útvonal megváltozik:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Host fejléc érvényesítés enegdélyezése</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Biztonság</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Ha a kategória mentési útja megváltozott:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Almappa készítése a több fájllal rendelkező torrentekhez</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>másodpercek</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Érintett torrentek kézi módba váltása</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Fájlok helye:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Kézi</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Torrent inaktivitási időzítő:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Alapértelmezett torrentkezelési mód:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Torrent hozzáadásakor</translation>
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Flags</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Kapcsolat</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Kliens</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Folyamat</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Letöltési sebesség</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Feltöltési sebesség</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Letöltve</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Feltöltve</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Relevancia</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Fájlok</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Ország</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Átlagos</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Magas</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maximális</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackerek</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Ügyfelek</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP Források</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Tartalom</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Letöltve:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Átvitel</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Aktív idő:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Várható befejezési idő:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Feltöltve:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Feltöltők</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Letöltési sebesség:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Feltöltési sebesség:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Ügyfelek:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Letöltési korlát:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Feltöltési korlát:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Elpazarolva:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Kapcsolatok:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Megjegyzés:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Megosztási arány:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Újra kapcsolódás:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Legutóbb befejezettként látva:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Teljes méret:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Szeletek:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Létrehozva általa:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Hozáadva</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Elkészült:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Készítés ideje:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent hash:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Mentés útvonala:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (van %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 ez a munkamenet)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (maximum %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (összes %2)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (átlag %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Letöltési korlát:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Feltöltési korlát:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Megfigyelt mappa</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Mentési hely felülírása</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Megfigyelt mappa</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Alapértelmezett mentési hely</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statisztika</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Felhasználói statisztikák</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Cache statisztika</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Olvasási gyorsítótár találatok:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Átlagos idő a várakozási sorban:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Kapcsolódott partnerek:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Összesített megosztási arány:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Összesített letöltés:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Munkamenet selejtje:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Összesített feltöltés</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Teljes pufferméret:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Teljesítmény statisztika</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Sorban várakozó I/O feladatok:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Írási gyorsítótár túlterheltsége:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Olvasási gyorsítótár túlterheltsége:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Összes sorban várakozó mérete:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 csomó</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Összes (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Letöltés (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Seed (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Elkészült (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Folytatott (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Szüneteltetve (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktív (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inaktív (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Hibás (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Összes (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Letöltés (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Seed (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Elkészült (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Szüneteltetve (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Folytatott (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktív (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inaktív (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Hibás (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Letöltési prioritás</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Hátramaradt</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Elérhetőség</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Név</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Méret</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Elkészült</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Feltöltők</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Peerek</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Letöltési sebesség</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Feltöltési sebesség</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Arány</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Idő</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategória</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Címkék</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Hozáadva</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Elkészült</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Letöltés limit</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Feltöltés limit</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Letöltve</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Feltöltve</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Munkamenet alatt letöltve</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Munkamenet alatt feltöltve</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Hátramaradt</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Aktív idő</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Mentés útvonala</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Elkészült</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Arány Korlát</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Legutóbb befejezettként látva</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Utolsó aktivítás</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Teljes méret</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Ügyfelek</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Üzenet</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Letöltve</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Tracker URL:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Frissítés...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Dolgozik</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Tiltva</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Még nem kapcsolódott</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Nem Alkalmazható</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Feltöltők</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Nem működik</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Tracker URL másolása</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Új tracker hozzáadása...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Tracker URL szerkesztése...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Tracker szerkesztés</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Letöltők</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Tracker eltávolítása</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Tracker hozzáadása</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Hozzáadandó trackerek listája (soronként egy):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 ideje</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Lefoglalás</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Szüneteltetve</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Elkészült</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Áthelyezés</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Seed</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Seed</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Sorban áll</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Letöltés</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Metaadatok letöltése</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Ellenőrzés</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Hiányzó fájlok</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Ellenőrzésre várakozik</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Folytatáshoz szükséges adatok ellenőrzése</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Elakadt</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategóriák</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torrent letöltés sebességkorlátozás</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torrent feltöltés sebességkorlátozás</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Erőltetett folytatás</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Megosztási arány korlát...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Feltöltési arány korlátozása...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Letöltési arány korlátozása...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Feljebb mozgat</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Lejjebb mozgat</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Legfelülre mozgat</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Legalúlra mozgat</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Hely megadása...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Név másolása</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Hash másolása</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Első és utolsó szelet letöltése először</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Alapértelmezett torrentkezelés</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategória</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Új…</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Visszaállítás</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorítás</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Kényszerített újraellenőrzés</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Magnet link másolása</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Szuper seed üzemmód</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Átnevezés...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Letöltés sorrendben</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Kényszerített újraellenőrzés</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Új kategória</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Új név</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Hely megadása</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Kényszerített újrajelentés</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Kategória Szerkesztése</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Mentés helye</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torrent fel/letöltés arány korlátozás</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Globális megosztási korlát használata</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Nincs megosztási korlát</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Megosztási korlát beállítása:</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>arány</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>perc</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Egy kifinomult, C++-ban fejlesztett BitTorrent kliens, Qt és libtorrent-rasterbar programkönyvtárakra alapozva.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Weblap:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Fórum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Hibakövető:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Törlés megerősítése</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Fájlok törlése a merevlemezről is</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Törlés megerősítése - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Letöltés URL-ekről</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Torrent Linkek Hozzáadása</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1ó %2p</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1nap %2ó</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1perc</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1perc</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>A mentési útvonal üres</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Plugin elérési útja:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL vagy helyi könyvtár</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Plugin telepítés</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Feltöltők:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Minden modul</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Kereső modulok...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Összes kategória</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Keresés itt:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Leírás oldal URL másolása</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Leírás oldal megnyitása</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Találatok</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Szűrő</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Csak torrentnevekben</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Csak az engedélyezettek</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>kívül</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Mindenhol</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Eltávolítás</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Új bővítmény telepítése</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Itt találhat új keresőmotor bővítményeket:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Telepített kereső modulok:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Engedélyezve</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Figyelmeztetés: Győződjön meg róla, hogy a keresőmotorok bármelyikéből származó torrentek letöltésekor betartja az ország szerzői jogi törvényeit.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Frissítések ellenőrzése</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Kereső modulok</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Letöltők</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Keresőmotor</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Feltöltők</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Engedélyezve</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzió</translation>
    </message>
</context>
</TS>